/*
 *  ======== mcu.h ========
 *  MCU hardware abstraction used sensor API implementations
 */
#ifndef MCU_I2C_H_
#define MCUI2C_H_

#include <stdint.h>

/* support C++ sources */
#ifdef __cplusplus
extern "C" {
#endif

/*
 *  ======== aurix_i2cInit ========
 *  Initialize the specified I2C bus for first use
 */
extern void mcu_i2cInit(uint8_t busId);

/*
 *  ======== aurix_i2cTransfer ========
 *  Transfer data to and from an I2C slave
 *
 *  If writeLength is non-zero, mcu_i2cTransfer always performs the write
 *  transfer first.
 *
 *  @param busId         id of an I2C bus to access for the transfer
 *  @param sensorAddress I2C address of peripheral to access
 *  @param dataToWrite   non-NULL pointer to a buffer of at least writeLength
 *                       bytes; may be NULL if writeLength = 0.
 *  @param writeLength   number of bytes to write from the dataToWrite array
 *  @param dataToRead    non-NULL pointer to a buffer of at least readLength
 *                       bytes; may be NULL if readLength = 0.
 *  @param readLength    number of bytes to read into dataToRead array
 *
 *  @return              0 if successful, otherwise non-zero
 */
extern int8_t mcu_i2cTransfer(uint8_t busId, uint8_t sensorAddress,
                              uint8_t *dataToWrite, uint8_t writeLength,
                              uint8_t *dataToRead,  uint8_t readLength);

/*
 *  ======== mcu_msWait ========
 *  Delay CPU for at least the specified number of milliseconds
 *
 *  @param msWait - number of milliseconds to delay, a value of 0 causes
 *                  this function to return immediately.
 */
extern void mcu_msWait(unsigned long msWait);

/* support C++ sources */
#ifdef __cplusplus
}
#endif
#endif

